summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoZoomMode.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoZoomMode.h')
-rw-r--r--lib/kofficeui/KoZoomMode.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/kofficeui/KoZoomMode.h b/lib/kofficeui/KoZoomMode.h
index 3e012f28..3c09d482 100644
--- a/lib/kofficeui/KoZoomMode.h
+++ b/lib/kofficeui/KoZoomMode.h
@@ -20,7 +20,7 @@
#ifndef _KOZOOMMODE_H_
#define _KOZOOMMODE_H_
-#include <qstring.h>
+#include <tqstring.h>
#include "koffice_export.h"
/**
@@ -37,15 +37,15 @@ public:
};
/// \param mode the mode name
- /// \return the to Mode converted QString \c mode
- static Mode toMode(const QString& mode);
+ /// \return the to Mode converted TQString \c mode
+ static Mode toMode(const TQString& mode);
- /// \return the to QString converted and translated Mode \c mode
- static QString toString(Mode mode);
+ /// \return the to TQString converted and translated Mode \c mode
+ static TQString toString(Mode mode);
/// \param mode the mode name
/// \return true if \c mode isn't dependent on windowsize
- static bool isConstant(const QString& mode)
+ static bool isConstant(const TQString& mode)
{ return toMode(mode) == ZOOM_CONSTANT; }
private:
static const char * modes[];